/**
 * PETALS - PETALS Services Platform. Copyright (c) 2008 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.component.framework.api;

import java.util.Map;
import java.util.logging.Logger;

import javax.jbi.component.ComponentContext;
import javax.jbi.component.ComponentLifeCycle;
import javax.jbi.messaging.DeliveryChannel;

import org.ow2.petals.component.framework.api.su.ServiceUnitExtensionsValidator;

/**
 * 
 * Created on 15 mai 2008
 * 
 * @author Christophe HAMERLING - EBM WebSourcing
 * @since 1.0
 * 
 */
public interface Component extends javax.jbi.component.Component, ComponentLifeCycle {

    /**
     * Returns the component delivery channel, used to send messages to petals
     * container
     * 
     * @return the delivery channel. Not null.
     */
    public DeliveryChannel getChannel();

    /**
     * The component context
     * 
     * @return the component context. Not null.
     */
    public ComponentContext getContext();

    /**
     * Returns the component logger
     * 
     * @return component logger. Not null.
     */
    public Logger getLogger();

    /**
     * Get the Service Unit validator.
     * 
     * @return the {@code ServiceUnitExtensionsValidator}
     */
    public ServiceUnitExtensionsValidator getServiceUnitExtensionsValidator();

    /**
     * Get all the interceptors
     * 
     * @return
     */
    public Map<String, Interceptor> getInterceptors();

    /**
     * Get the interceptor that have the given name.
     * 
     * @param name
     * @return null if the interceptor is not found of is there are no
     *         interceptor in the component
     */
    public Interceptor getInterceptor(final String name);

    /**
     * 
     * @param serviceUnitExtensionsValidator
     * @deprecated
     */
    public void setServiceUnitExtensionsValidator(
            final ServiceUnitExtensionsValidator serviceUnitExtensionsValidator);

    // public ComponentConfiguration getComponentConfiguration();

    /**
     * 
     * @return
     */
    // public JBIAcceptorManager getListenerManager();
    /**
     * Create a performance notification which the type RECEIVING_FROM_OUTSIDE
     * 
     * @return The performance notification to send.
     */
    // public PerformanceNotification
    // createPerformanceNotificationReceivingFromOutside(
    // final String userData, final Exchange msgExchange) throws JBIException;
    /**
     * Create a performance notification which the type SENDING_TO_OUTSIDE
     * 
     * @return The performance notification to send.
     */
    // public PerformanceNotification
    // createPerformanceNotificationSendingToOutside(
    // final String userData, final Exchange msgExchange) throws JBIException;
    /**
     * Create a performance notification which the type RECEIVING_FROM_NMR
     * 
     * @return The performance notification to send.
     */
    // public PerformanceNotification
    // createPerformanceNotificationReceivingFromNMR(
    // final String userData, final Exchange msgExchange) throws JBIException;
    /**
     * Create a performance notification which the type SENDING_TO_NMR
     * 
     * @return The performance notification to send.
     */
    // public PerformanceNotification createPerformanceNotificationSendingToNMR(
    // final String userData,
    // final Exchange msgExchange) throws JBIException;
    /**
     * Send a performance notification using the performance notifier
     * 
     * @param performanceNotification
     */
    // public void sendPerformanceNotification(final PerformanceNotification
    // performanceNotification) throws JBIException;
}
